@@ -4,6 +4,8 @@
  * Copyright 2014-2019 devemux86
  * Copyright 2017 usrusr
  * Copyright 2019 cpt1gl0
+ * Copyright 2019 Adrian Batzill
+ * Copyright 2019 mg4gh
  *
  * This program is free software: you can redistribute it and/or modify it under the
  * terms of the GNU Lesser General Public License as published by the Free Software
@@ -18,21 +20,15 @@
  */
 package org.mapsforge.map.android.graphics;
 
-import android.graphics.ColorFilter;
-import android.graphics.ColorMatrix;
-import android.graphics.ColorMatrixColorFilter;
-import android.graphics.PorterDuff;
-import android.graphics.Rect;
-import android.graphics.Region;
+import android.graphics.*;
 import android.os.Build;
-
 import org.mapsforge.core.graphics.Bitmap;
 import org.mapsforge.core.graphics.Canvas;
 import org.mapsforge.core.graphics.Color;
-import org.mapsforge.core.graphics.Filter;
 import org.mapsforge.core.graphics.Matrix;
 import org.mapsforge.core.graphics.Paint;
 import org.mapsforge.core.graphics.Path;
+import org.mapsforge.core.graphics.*;
 import org.mapsforge.core.model.Dimension;
 import org.mapsforge.core.model.Rectangle;
 
@@ -114,12 +110,19 @@ class AndroidCanvas implements Canvas {
     }
 
     @Override
-    public void drawBitmap(Bitmap bitmap, int left, int top, Filter filter) {
+    public void drawBitmap(Bitmap bitmap, int left, int top, float alpha, Filter filter) {
+        int oldAlpha = this.bitmapPaint.getAlpha();
+        if (alpha != 1) {
+            this.bitmapPaint.setAlpha((int) (alpha * 255));
+        }
         applyFilter(filter);
         this.canvas.drawBitmap(AndroidGraphicFactory.getBitmap(bitmap), left, top, bitmapPaint);
         if (filter != Filter.NONE) {
             bitmapPaint.setColorFilter(null);
         }
+        if (alpha != 1) {
+            this.bitmapPaint.setAlpha(oldAlpha);
+        }
     }
 
     @Override
@@ -128,12 +131,19 @@ class AndroidCanvas implements Canvas {
     }
 
     @Override
-    public void drawBitmap(Bitmap bitmap, Matrix matrix, Filter filter) {
+    public void drawBitmap(Bitmap bitmap, Matrix matrix, float alpha, Filter filter) {
+        int oldAlpha = this.bitmapPaint.getAlpha();
+        if (alpha != 1) {
+            this.bitmapPaint.setAlpha((int) (alpha * 255));
+        }
         applyFilter(filter);
         this.canvas.drawBitmap(AndroidGraphicFactory.getBitmap(bitmap), AndroidGraphicFactory.getMatrix(matrix), bitmapPaint);
         if (filter != Filter.NONE) {
             bitmapPaint.setColorFilter(null);
         }
+        if (alpha != 1) {
+            this.bitmapPaint.setAlpha(oldAlpha);
+        }
     }
 
     @Override
@@ -147,17 +157,22 @@ class AndroidCanvas implements Canvas {
 
     @Override
     public void drawBitmap(Bitmap bitmap, int srcLeft, int srcTop, int srcRight, int srcBottom,
-                           int dstLeft, int dstTop, int dstRight, int dstBottom, Filter filter) {
+                           int dstLeft, int dstTop, int dstRight, int dstBottom, float alpha, Filter filter) {
+        int oldAlpha = this.bitmapPaint.getAlpha();
+        if (alpha != 1) {
+            this.bitmapPaint.setAlpha((int) (alpha * 255));
+        }
         applyFilter(filter);
-
         this.canvas.drawBitmap(AndroidGraphicFactory.getBitmap(bitmap),
                 new Rect(srcLeft, srcTop, srcRight, srcBottom),
                 new Rect(dstLeft, dstTop, dstRight, dstBottom),
                 this.bitmapPaint);
-
         if (filter != Filter.NONE) {
             this.bitmapPaint.setColorFilter(null);
         }
+        if (alpha != 1) {
+            this.bitmapPaint.setAlpha(oldAlpha);
+        }
     }
 
     @Override
@@ -185,6 +200,20 @@ class AndroidCanvas implements Canvas {
         this.canvas.drawPath(AndroidGraphicFactory.getPath(path), AndroidGraphicFactory.getPaint(paint));
     }
 
+    @Override
+    public void drawPathText(String text, Path path, Paint paint) {
+        if (text == null || text.trim().isEmpty()) {
+            return;
+        }
+        if (paint.isTransparent()) {
+            return;
+        }
+
+        android.graphics.Paint androidPaint = AndroidGraphicFactory.getPaint(paint);
+        // Way text container was made larger by text height
+        this.canvas.drawTextOnPath(text, AndroidGraphicFactory.getPath(path), 0, androidPaint.getTextSize() / 4, androidPaint);
+    }
+
     @Override
     public void drawText(String text, int x, int y, Paint paint) {
         if (text == null || text.trim().isEmpty()) {
@@ -247,13 +276,10 @@ class AndroidCanvas implements Canvas {
         return this.bitmapPaint.isFilterBitmap();
     }
 
+    @SuppressWarnings("deprecation")
     @Override
     public void resetClip() {
-        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
-            this.canvas.save();
-            this.canvas.clipRect(0, 0, getWidth(), getHeight());
-            this.canvas.restore();
-        } else {
+        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.O) {
             this.canvas.clipRect(0, 0, getWidth(), getHeight(), Region.Op.REPLACE);
         }
     }
@@ -270,10 +296,15 @@ class AndroidCanvas implements Canvas {
 
     @Override
     public void setClip(int left, int top, int width, int height) {
+        setClip(left, top, width, height, false);
+    }
+
+    @Override
+    public void setClip(int left, int top, int width, int height, boolean intersect) {
         if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
-            this.canvas.save();
-            this.canvas.clipRect(left, top, left + width, top + height);
-            this.canvas.restore();
+            if (intersect) {
+                this.canvas.clipRect(left, top, left + width, top + height);
+            }
         } else {
             this.setClipInternal(left, top, width, height, Region.Op.REPLACE);
         }
@@ -281,10 +312,15 @@ class AndroidCanvas implements Canvas {
 
     @Override
     public void setClipDifference(int left, int top, int width, int height) {
-        this.setClipInternal(left, top, width, height, Region.Op.DIFFERENCE);
+        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
+            this.canvas.clipOutRect(left, top, left + width, top + height);
+        } else {
+            this.setClipInternal(left, top, width, height, Region.Op.DIFFERENCE);
+        }
     }
 
-    public void setClipInternal(int left, int top, int width, int height, Region.Op op) {
+    @SuppressWarnings("deprecation")
+    private void setClipInternal(int left, int top, int width, int height, Region.Op op) {
         this.canvas.clipRect(left, top, left + width, top + height, op);
     }
 
@@ -293,6 +329,7 @@ class AndroidCanvas implements Canvas {
         this.bitmapPaint.setFilterBitmap(filter);
     }
 
+    @SuppressWarnings("deprecation")
     @Override
     public void shadeBitmap(Bitmap bitmap, Rectangle hillRect, Rectangle tileRect, float magnitude) {
         this.canvas.save();
@@ -307,9 +344,7 @@ class AndroidCanvas implements Canvas {
         if (bitmap == null) {
             if (tileRect != null) {
                 if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
-                    this.canvas.save();
                     this.canvas.clipRect((float) tileRect.left, (float) tileRect.top, (float) tileRect.right, (float) tileRect.bottom);
-                    this.canvas.restore();
                 } else {
                     this.canvas.clipRect((float) tileRect.left, (float) tileRect.top, (float) tileRect.right, (float) tileRect.bottom, Region.Op.REPLACE);
                 }
@@ -328,9 +363,7 @@ class AndroidCanvas implements Canvas {
         if (horizontalScale < 1 && verticalScale < 1) {
             // fast path for wide zoom (downscaling)
             if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.O) {
-                this.canvas.save();
                 this.canvas.clipRect((float) tileRect.left, (float) tileRect.top, (float) tileRect.right, (float) tileRect.bottom);
-                this.canvas.restore();
             } else {
                 this.canvas.clipRect((float) tileRect.left, (float) tileRect.top, (float) tileRect.right, (float) tileRect.bottom, Region.Op.REPLACE);
             }
@@ -493,16 +526,16 @@ class AndroidCanvas implements Canvas {
             return tmpBitmap;
         }
 
-        public android.graphics.Paint useAlphaPaint(int alpha) {
+        android.graphics.Paint useAlphaPaint(int alpha) {
             shadePaint.setAlpha(alpha);
             return shadePaint;
         }
 
-        public android.graphics.Bitmap useNeutralShadingPixel() {
+        android.graphics.Bitmap useNeutralShadingPixel() {
             return neutralShadingPixel;
         }
 
-        public android.graphics.Matrix useMatrix() {
+        android.graphics.Matrix useMatrix() {
             if (tmpMatrix == null) {
                 tmpMatrix = new android.graphics.Matrix();
             }
