@@ -27,6 +27,7 @@ import org.mapsforge.map.layer.renderer.PolylineContainer;
 import org.mapsforge.map.model.DisplayModel;
 import org.mapsforge.map.rendertheme.RenderCallback;
 import org.mapsforge.map.rendertheme.RenderContext;
+import org.mapsforge.map.rendertheme.XmlThemeResourceProvider;
 import org.mapsforge.map.rendertheme.XmlUtils;
 import org.xmlpull.v1.XmlPullParser;
 import org.xmlpull.v1.XmlPullParserException;
@@ -53,17 +54,19 @@ public class LineSymbol extends RenderInstruction {
     private boolean repeat;
     private float repeatGap;
     private float repeatStart;
+    private final XmlThemeResourceProvider resourceProvider;
     private boolean rotate;
     private Scale scale = Scale.STROKE;
     private String src;
 
     public LineSymbol(GraphicFactory graphicFactory, DisplayModel displayModel, String elementName,
-                      XmlPullParser pullParser, String relativePathPrefix) throws IOException, XmlPullParserException {
+                      XmlPullParser pullParser, String relativePathPrefix, XmlThemeResourceProvider resourceProvider) throws IOException, XmlPullParserException {
         super(graphicFactory, displayModel);
 
         this.display = Display.IFSPACE;
         this.rotate = true;
         this.relativePathPrefix = relativePathPrefix;
+        this.resourceProvider = resourceProvider;
         this.dyScaled = new HashMap<>();
         // Probably not a good default, but backwards compatible
         this.position = Position.BELOW_RIGHT;
@@ -141,7 +144,7 @@ public class LineSymbol extends RenderInstruction {
 
         if (this.bitmap == null && !this.bitmapInvalid) {
             try {
-                this.bitmap = createBitmap(relativePathPrefix, src);
+                this.bitmap = createBitmap(relativePathPrefix, src, resourceProvider);
             } catch (IOException ioException) {
                 this.bitmapInvalid = true;
             }
