@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2019 devemux86
+ * Copyright 2018-2020 devemux86
  *
  * This program is free software: you can redistribute it and/or modify it under the
  * terms of the GNU Lesser General Public License as published by the Free Software
@@ -15,6 +15,9 @@
 package org.mapsforge.samples.android;
 
 import android.app.Activity;
+import android.content.Intent;
+import android.net.Uri;
+import android.os.Build;
 import android.os.Bundle;
 import org.mapsforge.core.model.LatLong;
 import org.mapsforge.map.android.graphics.AndroidGraphicFactory;
@@ -26,18 +29,17 @@ import org.mapsforge.map.layer.renderer.TileRendererLayer;
 import org.mapsforge.map.reader.MapFile;
 import org.mapsforge.map.rendertheme.InternalRenderTheme;
 
-import java.io.File;
+import java.io.FileInputStream;
 
 /**
  * A very basic Android app example.
  * <p>
- * You'll need a map with filename berlin.map from download.mapsforge.org in device storage:
- * /sdcard/Android/data/org.mapsforge.samples.android/files/
+ * You'll need a map with filename berlin.map from download.mapsforge.org in device storage.
  */
 public class GettingStarted extends Activity {
 
-    // Name of the map file in device storage
-    private static final String MAP_FILE = "berlin.map";
+    // Request code for selecting a map file
+    private static final int SELECT_MAP_FILE = 0;
 
     private MapView mapView;
 
@@ -66,6 +68,26 @@ public class GettingStarted extends Activity {
         mapView = new MapView(this);
         setContentView(mapView);
 
+        /*
+         * Open map.
+         */
+        Intent intent = new Intent(Build.VERSION.SDK_INT >= Build.VERSION_CODES.KITKAT ? Intent.ACTION_OPEN_DOCUMENT : Intent.ACTION_GET_CONTENT);
+        intent.addCategory(Intent.CATEGORY_OPENABLE);
+        intent.setType("*/*");
+        startActivityForResult(intent, SELECT_MAP_FILE);
+    }
+
+    @Override
+    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
+        if (requestCode == SELECT_MAP_FILE && resultCode == Activity.RESULT_OK) {
+            if (data != null) {
+                Uri uri = data.getData();
+                openMap(uri);
+            }
+        }
+    }
+
+    private void openMap(Uri uri) {
         try {
             /*
              * We then make some simple adjustments, such as showing a scale bar and zoom controls.
@@ -89,8 +111,8 @@ public class GettingStarted extends Activity {
              * tiles, a map file from which the tiles are generated and Rendertheme that defines the
              * appearance of the map.
              */
-            File mapFile = new File(getExternalFilesDir(null), MAP_FILE);
-            MapDataStore mapDataStore = new MapFile(mapFile);
+            FileInputStream fis = (FileInputStream) getContentResolver().openInputStream(uri);
+            MapDataStore mapDataStore = new MapFile(fis);
             TileRendererLayer tileRendererLayer = new TileRendererLayer(tileCache, mapDataStore,
                     mapView.getModel().mapViewPosition, AndroidGraphicFactory.INSTANCE);
             tileRendererLayer.setXmlRenderTheme(InternalRenderTheme.DEFAULT);
